@@ -17,12 +17,14 @@ THERMIA_API_CONFIG_URLS_BY_API_TYPE = {
 ###############################################################################
 
 REG_GROUP_TEMPERATURES = "REG_GROUP_TEMPERATURES"
+REG_GROUP_OPERATIONAL_STATUS = "REG_GROUP_OPERATIONAL_STATUS"
 REG_GROUP_OPERATIONAL_TIME = "REG_GROUP_OPERATIONAL_TIME"
 REG_GROUP_OPERATIONAL_OPERATION = "REG_GROUP_OPERATIONAL_OPERATION"
 REG_GROUP_HOT_WATER = "REG_GROUP_HOT_WATER"
 
 REGISTER_GROUPS = [
     REG_GROUP_TEMPERATURES,
+    REG_GROUP_OPERATIONAL_STATUS,
     REG_GROUP_OPERATIONAL_TIME,
     REG_GROUP_OPERATIONAL_OPERATION,
     REG_GROUP_HOT_WATER,
@@ -32,8 +34,8 @@ REGISTER_GROUPS = [
 # Temperature registers
 ###############################################################################
 
-REG_OUTDOOR_TEMPERATURE = "REG_OUTDOOR_TEMPERATURE" # Not used
-REG_OPER_DATA_OUTDOOR_TEMP_MA_SA = "REG_OPER_DATA_OUTDOOR_TEMP_MA_SA" # Not used
+REG_OUTDOOR_TEMPERATURE = "REG_OUTDOOR_TEMPERATURE"  # Not used
+REG_OPER_DATA_OUTDOOR_TEMP_MA_SA = "REG_OPER_DATA_OUTDOOR_TEMP_MA_SA"  # Not used
 REG_INDOOR_TEMPERATURE = "REG_INDOOR_TEMPERATURE"
 REG_SUPPLY_LINE = "REG_SUPPLY_LINE"
 REG_HOT_WATER_TEMPERATURE = "REG_HOT_WATER_TEMPERATURE"
